==> haskell-hls-stylish-haskell-plugin-2.1.0.0-78-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-stylish-haskell-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-stylish-haskell-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-stylish-haskell-plugin-2.1.0.0-JcpsHOFTcUy1hDgeCjsnXC
key:                  hls-stylish-haskell-plugin-2.1.0.0-JcpsHOFTcUy1hDgeCjsnXC
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Stylish Haskell code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  de1b8a539aaf303058723e5f9c0f2fd3
exposed:              True
exposed-modules:      Ide.Plugin.StylishHaskell
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-stylish-haskell-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-stylish-haskell-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-stylish-haskell-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-stylish-haskell-plugin
hs-libraries:         HShls-stylish-haskell-plugin-2.1.0.0-JcpsHOFTcUy1hDgeCjsnXC
depends:
    base-4.17.2.1 directory-1.3.7.1 filepath-1.4.2.2 ghc-9.4.8
    ghc-boot-th-9.4.8 ghcide-2.1.0.0-ARGjWBzXd216EBHbKqJoPL
    hls-plugin-api-2.1.0.0-7hxOgDDFJXq6y1VgYbGJHs
    lsp-types-2.0.1.0-17yE7LklXf32YKQbUHUjTz mtl-2.2.2
    stylish-haskell-0.14.4.0-9GEqJ8ZX6s44aolUPmP8Gr text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-stylish-haskell-plugin/html/hls-stylish-haskell-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-stylish-haskell-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-stylish-haskell-plugin-2.1.0.0-79-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-stylish-haskell-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-stylish-haskell-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-stylish-haskell-plugin-2.1.0.0-CHd1YAuUWLU5G3Yw72xef2
key:                  hls-stylish-haskell-plugin-2.1.0.0-CHd1YAuUWLU5G3Yw72xef2
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Stylish Haskell code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  6c2764d06569a8e5cebf2198bdca19c2
exposed:              True
exposed-modules:      Ide.Plugin.StylishHaskell
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-stylish-haskell-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-stylish-haskell-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-stylish-haskell-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-stylish-haskell-plugin
hs-libraries:         HShls-stylish-haskell-plugin-2.1.0.0-CHd1YAuUWLU5G3Yw72xef2
depends:
    base-4.17.2.1 directory-1.3.7.1 filepath-1.4.2.2 ghc-9.4.8
    ghc-boot-th-9.4.8 ghcide-2.1.0.0-EHKsnWxag352NCsLvNMT9Z
    hls-plugin-api-2.1.0.0-E35Co89Q3D8BS6iw2eiH
    lsp-types-2.0.1.0-17yE7LklXf32YKQbUHUjTz mtl-2.2.2
    stylish-haskell-0.14.4.0-9GEqJ8ZX6s44aolUPmP8Gr text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-stylish-haskell-plugin/html/hls-stylish-haskell-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-stylish-haskell-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
